#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default-instances-old-locale
version:              0.0.1
visibility:           public
id:
    data-default-instances-old-locale-0.0.1-LGvuKQiIExL2JkWmGWFD0W

key:
    data-default-instances-old-locale-0.0.1-LGvuKQiIExL2JkWmGWFD0W

license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             Default instances for types in old-locale
category:             Data
abi:                  667640a26b3f98f0dc5b26ee0e6b26cb
exposed:              True
exposed-modules:      Data.Default.Instances.OldLocale
import-dirs:
    /usr/lib/ghc-8.10.5/site-local/data-default-instances-old-locale-0.0.1

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/data-default-instances-old-locale-0.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/data-default-instances-old-locale-0.0.1

hs-libraries:
    HSdata-default-instances-old-locale-0.0.1-LGvuKQiIExL2JkWmGWFD0W

depends:
    base-4.14.2.0 data-default-class-0.1.2.0-9cFfQKP7sucLLfD3ZZyiPI
    old-locale-1.0.0.7-L6Wsx5CTYHFJNpULKIS1yv

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-old-locale/html/data-default-instances-old-locale.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-old-locale/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

